==> appsignal-1.0.3-py3-none-manylinux2014_i686.manylinux_2_15_i686.whl: appsignal/client.py <==
from __future__ import annotations

import logging
import os
import sys
from logging import DEBUG, ERROR, INFO, WARNING, Logger
from runpy import run_path
from typing import TYPE_CHECKING, ClassVar

from .agent import agent
from .config import Config, Options
from .opentelemetry import start_opentelemetry


if TYPE_CHECKING:
    from typing_extensions import Unpack


class Client:
    _logger: Logger
    _config: Config

    LOG_LEVELS: ClassVar[dict[str, int]] = {
        "error": ERROR,
        "warning": WARNING,
        "info": INFO,
        "debug": DEBUG,
        "trace": DEBUG,
    }

    # Load the AppSignal client from the app specific `__appsignal__.py` client
    # file. This loads the user config, rather than our default config.
    # If no client file is found it return `None`.
    # If there's a problem with the client file it will raise an
    # `InvalidClientFileError` with a message containing more details.
    @staticmethod
    def _load__appsignal__file() -> Client | None:
        cwd = os.getcwd()
        app_config_path = os.path.join(cwd, "__appsignal__.py")
        if os.path.exists(app_config_path):
            try:
                return run_path(app_config_path)["appsignal"]
            except KeyError as error:
                raise InvalidClientFileError(
                    "No `appsignal` variable was exported by the "
                    "__appsignal__.py config file. "
                    "Please update the __appsignal__.py file as described in "
                    "our documentation: "
                    "https://docs.appsignal.com/python/configuration.html"
                ) from error

        return None

    def __init__(self, **options: Unpack[Options]) -> None:
        self._config = Config(options)
        self.start_logger()

        if not self._config.is_active():
            self._logger.info("AppSignal not starting: no active config found")

    def start(self) -> None:
        if self._config.is_active():
            self._logger.info("Starting AppSignal")
            agent.start(self._config)
            start_opentelemetry(self._config)

    def start_logger(self) -> None:
        self._logger = logging.getLogger("appsignal")
        self._logger.setLevel(self.LOG_LEVELS[self._config.option("log_level")])

        if self._config.option("log") == "file":
            log_file_path = self._config.log_file_path()
            if log_file_path:
                handler = logging.FileHandler(log_file_path)
                handler.setFormatter(
                    logging.Formatter(
                        "[%(asctime)s (process) #%(process)d][%(levelname)s] "
                        "%(message)s",
                        "%Y-%m-%dT%H:%M:%S",
                    )
                )
                self._logger.addHandler(handler)
            else:
                self._start_stdout_logger()
        else:
            self._start_stdout_logger()

    def _start_stdout_logger(self) -> None:
        handler = logging.StreamHandler(sys.stdout)
        handler.setFormatter(
            logging.Formatter(
                "[%(asctime)s (process) #%(process)d][appsignal][%(levelname)s] "
                "%(message)s",
                "%Y-%m-%dT%H:%M:%S",
            )
        )
        self._logger.addHandler(handler)


class InvalidClientFileError(Exception):
    pass

==> appsignal-1.3.0-py3-none-manylinux2014_i686.manylinux_2_15_i686.whl: appsignal/client.py <==
from __future__ import annotations

import logging
import sys
from logging import DEBUG, ERROR, INFO, WARNING, Logger
from typing import TYPE_CHECKING, ClassVar

from .agent import agent
from .config import Config, Options
from .opentelemetry import start as start_opentelemetry
from .probes import start as start_probes


if TYPE_CHECKING:
    from typing_extensions import Unpack


_client: Client | None = None


def _reset_client() -> None:
    global _client
    _client = None


class Client:
    _logger: Logger
    _config: Config

    LOG_LEVELS: ClassVar[dict[str, int]] = {
        "error": ERROR,
        "warning": WARNING,
        "info": INFO,
        "debug": DEBUG,
        "trace": DEBUG,
    }

    def __init__(self, **options: Unpack[Options]) -> None:
        global _client

        self._config = Config(options)
        self._start_logger()
        _client = self

        if not self._config.is_active():
            self._logger.info("AppSignal not starting: no active config found")

    @classmethod
    def config(cls) -> Config | None:
        if _client is None:
            return None

        return _client._config

    def start(self) -> None:
        if self._config.is_active():
            self._logger.info("Starting AppSignal")
            agent.start(self._config)
            start_opentelemetry(self._config)
            self._start_probes()

    def _start_probes(self) -> None:
        if self._config.option("enable_minutely_probes"):
            start_probes()

    def _start_logger(self) -> None:
        self._logger = logging.getLogger("appsignal")
        self._logger.setLevel(self.LOG_LEVELS[self._config.option("log_level")])

        if self._config.option("log") == "file":
            log_file_path = self._config.log_file_path()
            if log_file_path:
                handler = logging.FileHandler(log_file_path)
                handler.setFormatter(
                    logging.Formatter(
                        "[%(asctime)s (process) #%(process)d][%(levelname)s] "
                        "%(message)s",
                        "%Y-%m-%dT%H:%M:%S",
                    )
                )
                self._logger.addHandler(handler)
            else:
                self._start_stdout_logger()
        else:
            self._start_stdout_logger()

    def _start_stdout_logger(self) -> None:
        handler = logging.StreamHandler(sys.stdout)
        handler.setFormatter(
            logging.Formatter(
                "[%(asctime)s (process) #%(process)d][appsignal][%(levelname)s] "
                "%(message)s",
                "%Y-%m-%dT%H:%M:%S",
            )
        )
        self._logger.addHandler(handler)
